summaryrefslogtreecommitdiff
path: root/include/linux/dma-resv.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/linux/dma-resv.h')
-rw-r--r--include/linux/dma-resv.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/linux/dma-resv.h b/include/linux/dma-resv.h
index 8dc19d65a217..3e0eefcead44 100644
--- a/include/linux/dma-resv.h
+++ b/include/linux/dma-resv.h
@@ -229,7 +229,7 @@ dma_resv_excl_fence(struct dma_resv *obj)
}
/**
* dma_resv_get_excl_rcu - get the reservation object's
* exclusive fence, without lock held.
* @obj: the reservation object
*
@@ -240,7 +240,7 @@ dma_resv_excl_fence(struct dma_resv *obj)
* The exclusive fence or NULL if none
*/
static inline struct dma_fence *
-dma_resv_get_excl_rcu(struct dma_resv *obj)
+dma_resv_get_excl_unlocked(struct dma_resv *obj)
{
struct dma_fence *fence;
@@ -229,7 +229,7 @@ dma_resv_excl_fence(struct dma_resv *obj)
}
/**
- * dma_resv_get_excl_rcu - get the reservation object's
+ * dma_resv_get_excl_unlocked - get the reservation object's
* exclusive fence, without lock held.
* @obj: the reservation object